from distutils.core import setup

setup(
    name='nlknhjc',
    version='1.2.0',
    py_modules= ['nlknhjc'],
    author='knhjc',
    author_email='rbshuangjinchao@163.com',
    url='http://www.baidu.com',
    description='A simple printer of nested lists',
)


"""the description"""


def nested_list(the_list, level=0):
    """the description"""
    for item in the_list:
        if isinstance(item, list):
            nested_list(item, level+1)
        else:
            for tab_stop in range(level):
                print("\t", end="")
            print(item)
